import type { NextPage } from "next";
import Link from "next/link";
import { useRouter } from "next/router";
import { ExpressionSetInfo } from "../../components/ExpressionSetInfo/ExpressionSetInfo";
import { Page } from "../../components/Page";
import { useExpressionData } from "../../hooks/useExpressionData";

const ExpressionSetDetailsPage: NextPage = () => {
  const { query } = useRouter();
  const { expression_sets, expression_to_expression_set } = useExpressionData();

  // Fallback for expression set not found
  const expression_set_id = Number.parseInt(query["set-id"] as string);
  const expression_set = expression_sets.find(
    (item) => item.id === expression_set_id
  );
  if (!expression_set)
    return (
      <Page>
        <p className="details">Expression set not found</p>
      </Page>
    );

  // Fallback for expression set empty
  const word_count = expression_to_expression_set.filter(
    (item) => item.expression_set_id === expression_set.id
  ).length;
  if (!word_count)
    return (
      <Page>
        <div className="expression-set-page">
          <ExpressionSetInfo
            id={expression_set.id}
            name={expression_set.name}
            description={expression_set.description}
            word_count={word_count}
          />
          <p className="text-details">No expressions left in this set.</p>
        </div>
      </Page>
    );

  return (
    <Page>
      <div className="expression-set-page">
        <ExpressionSetInfo
          id={expression_set.id}
          name={expression_set.name}
          description={expression_set.description}
          word_count={word_count}
        />
        <p className="text-details grow">{/* TODO other details */}</p>
        <Link
          href={{
            pathname: "/expression-sets/practice",
            query: { "set-id": expression_set.id },
          }}
          passHref
        >
          <a className="navigation-item text-navigation">
            <span>Practice this set</span>
          </a>
        </Link>
      </div>
    </Page>
  );
};

export default ExpressionSetDetailsPage;
